@@ -46,6 +46,10 @@ class CTkProgressBar(tkinter.Frame):
         # set progress
         self.set(self.value)
 
+    def destroy(self):
+        AppearanceModeTracker.remove(self.change_appearance_mode)
+        super().destroy()
+
     def detect_color_of_master(self):
         if isinstance(self.master, CTkFrame):
             return self.master.fg_color
